@@ -22,11 +22,6 @@ package com.verisign.epp.codec.contact;
 import java.util.Date;
 import java.util.Vector;
 
-import junit.framework.Assert;
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import com.verisign.epp.codec.gen.EPPAuthInfo;
 import com.verisign.epp.codec.gen.EPPCodecException;
 import com.verisign.epp.codec.gen.EPPCodecTst;
@@ -38,6 +33,11 @@ import com.verisign.epp.codec.gen.EPPResult;
 import com.verisign.epp.codec.gen.EPPTransId;
 import com.verisign.epp.util.TestThread;
 
+import junit.framework.Assert;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
+
 /**
  * Is a unit test of the com.verisign.epp.codec.contact package. The unit test
  * will execute, gather statistics, and output the results of a test of each
@@ -185,32 +185,17 @@ public class EPPContactTst extends TestCase {
 		theCommand.setVoice("+1.7035555555");
 		theCommand.setVoiceExt("456");
 
-		// disclose names
-		Vector names = new Vector();
-
-		// names.addElement(new
-		// EPPContactDiscloseName(EPPContactDiscloseName.ATTR_TYPE_LOC));
-		names.addElement(new EPPContactDiscloseName(EPPContactDiscloseName.ATTR_TYPE_INT));
-
-		// disclose orgs
-		Vector orgs = new Vector();
-		orgs.addElement(new EPPContactDiscloseOrg(EPPContactDiscloseOrg.ATTR_TYPE_LOC));
-		orgs.addElement(new EPPContactDiscloseOrg(EPPContactDiscloseOrg.ATTR_TYPE_INT));
-
-		// disclose addresses
-		Vector addresses = new Vector();
-		addresses.addElement(new EPPContactDiscloseAddress(EPPContactDiscloseAddress.ATTR_TYPE_LOC));
-		addresses.addElement(new EPPContactDiscloseAddress(EPPContactDiscloseAddress.ATTR_TYPE_INT));
-
-		// disclose
 		EPPContactDisclose disclose = new EPPContactDisclose();
-		disclose.setFlag("0");
-		disclose.setNames(names);
-		disclose.setOrgs(orgs);
-		disclose.setAddresses(addresses);
-		disclose.setVoice("");
-		disclose.setFax("");
-		disclose.setEmail("");
+		disclose.setFlag(false);
+		disclose.setNameInt(true);
+		disclose.setNameLoc(true);
+		disclose.setOrgInt(true);
+		disclose.setOrgLoc(true);
+		disclose.setAddrInt(true);
+		disclose.setAddrLoc(true);
+		disclose.setVoice(false);
+		disclose.setFax(false);
+		disclose.setEmail(false);
 
 		theCommand.setDisclose(disclose);
 
@@ -351,32 +336,17 @@ public class EPPContactTst extends TestCase {
 		change.setFax("+1.7037777777");
 		change.setFaxExt("678");
 
-		// disclose names
-		Vector names = new Vector();
-
-		// names.addElement(new
-		// EPPContactDiscloseName(EPPContactDiscloseName.ATTR_TYPE_LOC));
-		names.addElement(new EPPContactDiscloseName(EPPContactDiscloseName.ATTR_TYPE_INT));
-
-		// disclose orgs
-		Vector orgs = new Vector();
-		orgs.addElement(new EPPContactDiscloseOrg(EPPContactDiscloseOrg.ATTR_TYPE_LOC));
-		orgs.addElement(new EPPContactDiscloseOrg(EPPContactDiscloseOrg.ATTR_TYPE_INT));
-
-		// disclose addresses
-		Vector addresses = new Vector();
-		addresses.addElement(new EPPContactDiscloseAddress(EPPContactDiscloseAddress.ATTR_TYPE_LOC));
-		addresses.addElement(new EPPContactDiscloseAddress(EPPContactDiscloseAddress.ATTR_TYPE_INT));
-
-		// disclose
 		EPPContactDisclose disclose = new EPPContactDisclose();
-		disclose.setFlag("0");
-		disclose.setNames(names);
-		disclose.setOrgs(orgs);
-		disclose.setAddresses(addresses);
-		disclose.setVoice("");
-		disclose.setFax("");
-		disclose.setEmail("");
+		disclose.setFlag(false);
+		disclose.setNameInt(true);
+		disclose.setNameLoc(true);
+		disclose.setOrgInt(true);
+		disclose.setOrgLoc(true);
+		disclose.setAddrInt(true);
+		disclose.setAddrLoc(true);
+		disclose.setVoice(false);
+		disclose.setFax(false);
+		disclose.setEmail(false);
 
 		change.setDisclose(disclose);
 
