@@ -685,7 +685,7 @@ public class EPPDefRegTst extends TestCase {
 		EPPDefRegCheckResult defRegResult =
 			new EPPDefRegCheckResult("ash.ibm.com", "standard", false);
 
-		defRegResult.setDefRegReason("In Use");
+		defRegResult.setDefRegReason("In use");
 
 		defRegResult.setLanguage("fr");
 
