@@ -485,6 +485,15 @@ public class EPPCredentials
         return EPPUtil.toString(this);
     } // End EPPCredentials.toString()
 
+ 	/**
+ 	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+ 	 * 
+ 	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+ 	 */
+ 	@Override
+ 	public String getNamespace() {
+ 		return EPPCodec.NS;
+ 	}
 
     /**
      * Client login id
