@@ -409,90 +409,90 @@ public class EPPResult implements EPPCodecComponent {
 	// Static Initializer for EPPResult
 	static {
 		defaultMsg = new Hashtable();
-		defaultMsg.put(new Integer(SUCCESS), "Command completed successfully");
+		defaultMsg.put(Integer.valueOf(SUCCESS), "Command completed successfully");
 		defaultMsg.put(
-					   new Integer(SUCCESS_PENDING),
+					   Integer.valueOf(SUCCESS_PENDING),
 					   "Command completed successfully; action pending");
 		defaultMsg.put(
-					   new Integer(SUCCESS_POLL_NO_MSGS),
+					   Integer.valueOf(SUCCESS_POLL_NO_MSGS),
 					   "Command completed successfully; no messages");
 		defaultMsg.put(
-					   new Integer(SUCCESS_POLL_MSG),
+					   Integer.valueOf(SUCCESS_POLL_MSG),
 					   "Command completed successfully; ack to dequeue");
 		defaultMsg.put(
-					   new Integer(SUCCESS_END_SESSION),
+					   Integer.valueOf(SUCCESS_END_SESSION),
 					   "Command completed successfully; ending session");
-		defaultMsg.put(new Integer(UNKNOWN_COMMAND), "Unknown command");
+		defaultMsg.put(Integer.valueOf(UNKNOWN_COMMAND), "Unknown command");
 		defaultMsg.put(
-					   new Integer(COMMAND_SYNTAX_ERROR), "Command syntax error");
-		defaultMsg.put(new Integer(COMMAND_USE_ERROR), "Command use error");
+					   Integer.valueOf(COMMAND_SYNTAX_ERROR), "Command syntax error");
+		defaultMsg.put(Integer.valueOf(COMMAND_USE_ERROR), "Command use error");
 		defaultMsg.put(
-					   new Integer(MISSING_PARAMETER),
+					   Integer.valueOf(MISSING_PARAMETER),
 					   "Required parameter missing");
 		defaultMsg.put(
-					   new Integer(PARAM_OUT_OF_RANGE),
+					   Integer.valueOf(PARAM_OUT_OF_RANGE),
 					   "Parameter value range error");
 		defaultMsg.put(
-					   new Integer(PARAM_SYNTAX_ERROR),
+					   Integer.valueOf(PARAM_SYNTAX_ERROR),
 					   "Parameter value syntax error");
 		defaultMsg.put(
-					   new Integer(UNIMPLEMENTED_VERSION),
+					   Integer.valueOf(UNIMPLEMENTED_VERSION),
 					   "Unimplemented protocol version");
 		defaultMsg.put(
-					   new Integer(UNIMPLEMENTED_COMMAND),
+					   Integer.valueOf(UNIMPLEMENTED_COMMAND),
 					   "Unimplemented command");
 		defaultMsg.put(
-					   new Integer(UNIMPLEMENTED_OPTION), "Unimplemented option");
+					   Integer.valueOf(UNIMPLEMENTED_OPTION), "Unimplemented option");
 		defaultMsg.put(
-					   new Integer(UNIMPLEMENTED_EXTENSION),
+					   Integer.valueOf(UNIMPLEMENTED_EXTENSION),
 					   "Unimplemented extension");
-		defaultMsg.put(new Integer(BILLING_ERROR), "Billing failure");
+		defaultMsg.put(Integer.valueOf(BILLING_ERROR), "Billing failure");
 		defaultMsg.put(
-					   new Integer(NOT_RENEWABLE),
+					   Integer.valueOf(NOT_RENEWABLE),
 					   "Object is not eligible for renewal");
 		defaultMsg.put(
-					   new Integer(NOT_TRANSFERABLE),
+					   Integer.valueOf(NOT_TRANSFERABLE),
 					   "Object is not eligible for transfer");
 		defaultMsg.put(
-					   new Integer(AUTHENTICATION_ERROR), "Authentication error");
-		defaultMsg.put(new Integer(AUTHORIZATION_ERROR), "Authorization error");
+					   Integer.valueOf(AUTHENTICATION_ERROR), "Authentication error");
+		defaultMsg.put(Integer.valueOf(AUTHORIZATION_ERROR), "Authorization error");
 		defaultMsg.put(
-					   new Integer(INVALID_AUTHORIZATION_INFO),
+					   Integer.valueOf(INVALID_AUTHORIZATION_INFO),
 					   "Invalid authorization information");
 		defaultMsg.put(
-					   new Integer(OBJECT_PENDING_TRANSFER),
+					   Integer.valueOf(OBJECT_PENDING_TRANSFER),
 					   "Object pending transfer");
 		defaultMsg.put(
-					   new Integer(OBJECT_NOT_PENDING_TRANSFER),
+					   Integer.valueOf(OBJECT_NOT_PENDING_TRANSFER),
 					   "Object not pending transfer");
-		defaultMsg.put(new Integer(OBJECT_EXISTS), "Object exists");
+		defaultMsg.put(Integer.valueOf(OBJECT_EXISTS), "Object exists");
 		defaultMsg.put(
-					   new Integer(OBJECT_DOES_NOT_EXIST),
+					   Integer.valueOf(OBJECT_DOES_NOT_EXIST),
 					   "Object does not exist");
 		defaultMsg.put(
-					   new Integer(STATUS_PROHIBITS_OP),
+					   Integer.valueOf(STATUS_PROHIBITS_OP),
 					   "Object status prohibits operation");
 		defaultMsg.put(
-					   new Integer(ASSOC_PROHIBITS_OP),
+					   Integer.valueOf(ASSOC_PROHIBITS_OP),
 					   "Object association prohibits operation");
 		defaultMsg.put(
-					   new Integer(PARAM_VALUE_POLICY_ERROR),
+					   Integer.valueOf(PARAM_VALUE_POLICY_ERROR),
 					   "Parameter value policy error");
 		defaultMsg.put(
-					   new Integer(UNIMPLEMENTED_OBJECT_SERVICE),
+					   Integer.valueOf(UNIMPLEMENTED_OBJECT_SERVICE),
 					   "Unimplemented object service");
 		defaultMsg.put(
-					   new Integer(DATA_MGT_POLICY_VIOLATION),
+					   Integer.valueOf(DATA_MGT_POLICY_VIOLATION),
 					   "Data management policy violation");
-		defaultMsg.put(new Integer(COMMAND_FAILED), "Command failed");
+		defaultMsg.put(Integer.valueOf(COMMAND_FAILED), "Command failed");
 		defaultMsg.put(
-					   new Integer(COMMAND_FAILED_END),
+					   Integer.valueOf(COMMAND_FAILED_END),
 					   "Command failed; server closing connection");
 		defaultMsg.put(
-					   new Integer(AUTHENTICATION_ERROR_END),
+					   Integer.valueOf(AUTHENTICATION_ERROR_END),
 					   "Authentication error; server closing connection");
 		defaultMsg.put(
-					   new Integer(SESSION_LIMIT_END),
+					   Integer.valueOf(SESSION_LIMIT_END),
 					   "Session limit exceeded; server closing connection");
 	}
 
@@ -570,7 +570,7 @@ public class EPPResult implements EPPCodecComponent {
 	 */
 	public EPPResult() {
 		code	    = SUCCESS;
-		message     = (String) defaultMsg.get(new Integer(code));
+		message     = (String) defaultMsg.get(Integer.valueOf(code));
 	}
 
 	// End EPPResult.EPPResult()
@@ -597,7 +597,7 @@ public class EPPResult implements EPPCodecComponent {
 	 */
 	public EPPResult(int aCode) {
 		code	    = aCode;
-		message     = (String) defaultMsg.get(new Integer(aCode));
+		message     = (String) defaultMsg.get(Integer.valueOf(aCode));
 	}
 
 	// End EPPResult.EPPResult(int)
@@ -1167,7 +1167,7 @@ public class EPPResult implements EPPCodecComponent {
 		code = aCode;
 
 		if (aUseDefaultMessage) {
-			message = (String) defaultMsg.get(new Integer(aCode));
+			message = (String) defaultMsg.get(Integer.valueOf(aCode));
 		}
 	}
 
@@ -1304,7 +1304,15 @@ public class EPPResult implements EPPCodecComponent {
 		return EPPUtil.toString(this);
 	}
 
-	// End EPPResult.toString()
+	/**
+	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 */
+	@Override
+	public String getNamespace() {
+		return EPPCodec.NS;
+	}
 }
 
 
