@@ -35,6 +35,7 @@ import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPGreeting;
 import com.verisign.epp.codec.gen.EPPMessage;
 import com.verisign.epp.codec.gen.EPPResponse;
+import com.verisign.epp.codec.gen.EPPResult;
 import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
@@ -74,16 +75,14 @@ public class EPPSessionTst extends TestCase {
 	 * Handle to the Singleton EPP Application instance (
 	 * <code>EPPApplicationSingle</code>)
 	 */
-	private static EPPApplicationSingle app = EPPApplicationSingle
-			.getInstance();
+	private static EPPApplicationSingle app = EPPApplicationSingle.getInstance();
 
 	/** Name of configuration file to use for test (default = epp.config). */
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(
-			EPPSessionTst.class.getName(),
-			EPPCatFactory.getInstance().getFactory());
+	private static final Logger cat = Logger.getLogger(EPPSessionTst.class.getName(),
+	      EPPCatFactory.getInstance().getFactory());
 
 	/** EPP Session associated with test */
 	private EPPSession session = null;
@@ -94,14 +93,12 @@ public class EPPSessionTst extends TestCase {
 	 * logical name.
 	 *
 	 * @param name
-	 *            Logical name of the test
+	 *           Logical name of the test
 	 */
 	public EPPSessionTst(String name) {
 		super(name);
 	}
 
-	// End EPPSessionTst(String)
-
 	/**
 	 * JUNIT test method to implement the <code>EPPSessionTst TestCase</code>.
 	 * Each sub-test will be invoked in order to satisfy testing the
@@ -111,6 +108,7 @@ public class EPPSessionTst extends TestCase {
 		initSession();
 		doHello();
 		doPoll();
+		doPollConsume();
 		doAsyncPoll();
 		doSendPacket();
 		doSendInvalidRequest();
@@ -118,17 +116,15 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * Unit test of <code>EPPSession.initSession</code>. The session attribute
-	 * is initialized with the attributes defined in the EPP sample files.
+	 * Unit test of <code>EPPSession.initSession</code>. The session attribute is
+	 * initialized with the attributes defined in the EPP sample files.
 	 */
 	private void initSession() {
 		printStart("initSession");
 
 		// Get client id and password from configuration if defined
-		String theClientId = Environment.getProperty("EPP.Test.clientId",
-				"ClientX");
-		String thePassword = Environment.getProperty("EPP.Test.password",
-				"foo-BAR2");
+		String theClientId = Environment.getProperty("EPP.Test.clientId", "ClientX");
+		String thePassword = Environment.getProperty("EPP.Test.password", "foo-BAR2");
 
 		// Set attributes for initSession
 		session.setClientID(theClientId);
@@ -179,8 +175,8 @@ public class EPPSessionTst extends TestCase {
 
 			// Send packet over session
 			session.sendPacket(
-					"<?xml version=\"1.0\" encoding=\"UTF-8\"?><epp xmlns=\"urn:ietf:params:xml:ns:epp-1.0\"><hello/></epp>"
-							.getBytes());
+			      "<?xml version=\"1.0\" encoding=\"UTF-8\"?><epp xmlns=\"urn:ietf:params:xml:ns:epp-1.0\"><hello/></epp>"
+			            .getBytes());
 
 			// Read the greeting
 			Document theDoc = null;
@@ -190,14 +186,11 @@ public class EPPSessionTst extends TestCase {
 
 			// Decode DOM Document to <code>EPPGreeting</code> instance
 			try {
-				EPPGreeting greeting = (EPPGreeting) EPPCodec.getInstance()
-						.decode(theDoc);
-				System.out.println(
-						"doSendPacket: Greeting = [" + greeting + "]\n\n");
+				EPPGreeting greeting = (EPPGreeting) EPPCodec.getInstance().decode(theDoc);
+				System.out.println("doSendPacket: Greeting = [" + greeting + "]\n\n");
 			}
 			catch (EPPDecodeException ex) {
-				Assert.fail(
-						"doSendPacket(); Error reading the greeting after a hello");
+				Assert.fail("doSendPacket(); Error reading the greeting after a hello");
 			}
 		}
 		catch (EPPCommandException e) {
@@ -227,25 +220,21 @@ public class EPPSessionTst extends TestCase {
 
 			// Decode DOM Document to <code>EPPResponse</code> instance
 			try {
-				EPPResponse response = (EPPResponse) EPPCodec.getInstance()
-						.decode(theDoc);
-				System.out.println("doSendInvalidRequest: Response = ["
-						+ response + "]\n\n");
+				EPPResponse response = (EPPResponse) EPPCodec.getInstance().decode(theDoc);
+				System.out.println("doSendInvalidRequest: Response = [" + response + "]\n\n");
 				if (response.isSuccess()) {
 					Assert.fail(
-							"doSendInvalidRequest(); Error receiving successful response after sending invalid request (response)");
+					      "doSendInvalidRequest(); Error receiving successful response after sending invalid request (response)");
 				}
 			}
 			catch (EPPDecodeException ex) {
-				Assert.fail(
-						"doSendInvalidRequest(); Error reading the response after sending invalid request (response)");
+				Assert.fail("doSendInvalidRequest(); Error reading the response after sending invalid request (response)");
 			}
 
 			// Send an EPP Greeting
 			EPPGreeting greeting = new EPPGreeting();
 			greeting.setServer("doSendInvalidRequest");
-			
-			
+
 			// Attempt to send an EPPGreeting
 			this.session.sendMessage(greeting);
 
@@ -257,18 +246,15 @@ public class EPPSessionTst extends TestCase {
 
 			// Decode DOM Document to <code>EPPResponse</code> instance
 			try {
-				EPPResponse response = (EPPResponse) EPPCodec.getInstance()
-						.decode(theDoc);
-				System.out.println("doSendInvalidRequest: Response = ["
-						+ response + "]\n\n");
+				EPPResponse response = (EPPResponse) EPPCodec.getInstance().decode(theDoc);
+				System.out.println("doSendInvalidRequest: Response = [" + response + "]\n\n");
 				if (response.isSuccess()) {
 					Assert.fail(
-							"doSendInvalidRequest(); Error receiving successful response after sending invalid request (greeting)");
+					      "doSendInvalidRequest(); Error receiving successful response after sending invalid request (greeting)");
 				}
 			}
 			catch (EPPDecodeException ex) {
-				Assert.fail(
-						"doSendInvalidRequest(); Error reading the response after sending invalid request (greeting)");
+				Assert.fail("doSendInvalidRequest(); Error reading the response after sending invalid request (greeting)");
 			}
 
 		}
@@ -283,7 +269,7 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * Unit test of <code>EPPSession.sendHello</code> command.
+	 * Unit test of <code>EPPSession.sendPoll</code> command.
 	 */
 	private void doPoll() {
 		printStart("doPoll");
@@ -320,13 +306,50 @@ public class EPPSessionTst extends TestCase {
 		}
 		catch (EPPCommandException e) {
 			// Expect error
-			System.out.println(
-					"doPoll: Error Response = [" + e.getResponse() + "]\n\n");
+			System.out.println("doPoll: Error Response = [" + e.getResponse() + "]\n\n");
 		}
 
 		printEnd("doPoll");
 	}
 
+	/**
+	 * Read all of the poll queue messages from the poll queue via the
+	 * <code>EPPSession.sendPoll</code> command.
+	 */
+	private void doPollConsume() {
+		printStart("doPollConsume");
+
+		EPPResponse response = null;
+
+		try {
+			session.setTransId("ABC-" + System.currentTimeMillis());
+			session.setPollOp(EPPSession.OP_REQ);
+			response = session.sendPoll();
+
+			while (response.getResult().getCode() == EPPResult.SUCCESS_POLL_MSG) {
+
+				System.out.println("doPollConsume: Message = [" + response + "]\n\n");
+
+				// Acknowledge current message
+				session.setTransId("ABC-" + System.currentTimeMillis());
+				session.setPollOp(EPPSession.OP_ACK);
+				session.setMsgID(response.getMsgQueue().getId());
+				response = session.sendPoll();
+
+				// Send next poll request
+				session.setTransId("ABC-" + System.currentTimeMillis());
+				session.setPollOp(EPPSession.OP_REQ);
+				response = session.sendPoll();
+			}
+
+		}
+		catch (EPPCommandException e) {
+			handleException(e);
+		}
+
+		printEnd("doPollConsume");
+	}
+
 	/**
 	 * Unit test processing poll responses asynchronous from the commands. This
 	 * is a test of the use of pipelining.
@@ -336,8 +359,7 @@ public class EPPSessionTst extends TestCase {
 
 		if (!session.isModeSupported(EPPSession.MODE_ASYNC)) {
 			System.out.println(
-					"doAsyncPoll: Session " + session.getClass().getName()
-							+ " does not support MODE_ASYNC, skipping test");
+			      "doAsyncPoll: Session " + session.getClass().getName() + " does not support MODE_ASYNC, skipping test");
 			printEnd("doAsyncPoll (skipped)");
 			return;
 		}
@@ -349,16 +371,13 @@ public class EPPSessionTst extends TestCase {
 			session.setPollOp(EPPSession.OP_REQ);
 			EPPResponse thePollResp = session.sendPoll();
 
-			Assert.assertNull("doAsyncPoll: sendPoll() response " + thePollResp
-					+ " != null", thePollResp);
+			Assert.assertNull("doAsyncPoll: sendPoll() response " + thePollResp + " != null", thePollResp);
 
 			// Asynchronously read the poll response
 			EPPResponse theResponse = session.readResponse();
 
-			Assert.assertEquals(
-					"doAsyncPoll: clientTransId's don't Match (command and response)",
-					theClientTransId,
-					theResponse.getTransId().getClientTransId());
+			Assert.assertEquals("doAsyncPoll: clientTransId's don't Match (command and response)", theClientTransId,
+			      theResponse.getTransId().getClientTransId());
 		}
 		catch (EPPCommandException e) {
 			handleException(e);
@@ -403,16 +422,13 @@ public class EPPSessionTst extends TestCase {
 					Class theSessionClass = Class.forName(theSessionClassName);
 
 					if (!EPPSession.class.isAssignableFrom((theSessionClass))) {
-						Assert.fail(theSessionClassName
-								+ " is not a subclass of EPPSession");
+						Assert.fail(theSessionClassName + " is not a subclass of EPPSession");
 					}
 
-					session = (EPPSession) theSessionClass.newInstance();
+					session = (EPPSession) theSessionClass.getDeclaredConstructor().newInstance();
 				}
 				catch (Exception ex) {
-					Assert.fail(
-							"Exception instantiating EPP.SessionClass value "
-									+ theSessionClassName + ": " + ex);
+					Assert.fail("Exception instantiating EPP.SessionClass value " + theSessionClassName + ": " + ex);
 				}
 			}
 			else {
@@ -434,8 +450,8 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * JUNIT <code>suite</code> static method, which returns the tests
-	 * associated with <code>EPPSessionTst</code>.
+	 * JUNIT <code>suite</code> static method, which returns the tests associated
+	 * with <code>EPPSessionTst</code>.
 	 *
 	 * @return DOCUMENT ME!
 	 */
@@ -463,13 +479,13 @@ public class EPPSessionTst extends TestCase {
 	 * <ul>
 	 * <li>iterations Number of unit test iterations to run</li>
 	 * <li>validate Turn XML validation on (<code>true</code>) or off (
-	 * <code>false</code>). If validate is not specified, validation will be
-	 * off.</li>
+	 * <code>false</code>). If validate is not specified, validation will be off.
+	 * </li>
 	 * </ul>
 	 * 
 	 *
 	 * @param args
-	 *            DOCUMENT ME!
+	 *           DOCUMENT ME!
 	 */
 	public static void main(String[] args) {
 		// Override the default configuration file name?
@@ -489,8 +505,7 @@ public class EPPSessionTst extends TestCase {
 		if (numThreads > 1) {
 			// Spawn each thread passing in the Test Suite
 			for (int i = 0; i < numThreads; i++) {
-				TestThread thread = new TestThread("EPPSessionTst Thread " + i,
-						EPPSessionTst.suite());
+				TestThread thread = new TestThread("EPPSessionTst Thread " + i, EPPSessionTst.suite());
 				thread.start();
 			}
 		}
@@ -511,11 +526,11 @@ public class EPPSessionTst extends TestCase {
 	 * Handle an <code>EPPCommandException</code>, which can be either a server
 	 * generated error or a general exception. If the exception was caused by a
 	 * server error, "Server Error : &lt;Response XML&gt;" will be specified. If
-	 * the exception was caused by a general algorithm error,
-	 * "General Error : &lt;Exception Description&gt;" will be specified.
+	 * the exception was caused by a general algorithm error, "General Error :
+	 * &lt;Exception Description&gt;" will be specified.
 	 *
 	 * @param aException
-	 *            Exception thrown during test
+	 *           Exception thrown during test
 	 */
 	public void handleException(EPPCommandException aException) {
 		EPPResponse response = session.getResponse();
@@ -531,22 +546,20 @@ public class EPPSessionTst extends TestCase {
 	}
 
 	/**
-	 * Print the start of a test with the <code>Thread</code> name if the
-	 * current thread is a <code>TestThread</code>.
+	 * Print the start of a test with the <code>Thread</code> name if the current
+	 * thread is a <code>TestThread</code>.
 	 *
 	 * @param aTest
-	 *            name for the test
+	 *           name for the test
 	 */
 	public static void printStart(String aTest) {
 		if (Thread.currentThread() instanceof TestThread) {
 			System.out.print(Thread.currentThread().getName() + ": ");
-			cat.info(
-					Thread.currentThread().getName() + ": " + aTest + " Start");
+			cat.info(Thread.currentThread().getName() + ": " + aTest + " Start");
 		}
 
 		System.out.println("Start of " + aTest);
-		System.out.println(
-				"****************************************************************\n");
+		System.out.println("****************************************************************\n");
 	}
 
 	/**
@@ -554,11 +567,10 @@ public class EPPSessionTst extends TestCase {
 	 * thread is a <code>TestThread</code>.
 	 *
 	 * @param aTest
-	 *            name for the test
+	 *           name for the test
 	 */
 	public static void printEnd(String aTest) {
-		System.out.println(
-				"****************************************************************");
+		System.out.println("****************************************************************");
 
 		if (Thread.currentThread() instanceof TestThread) {
 			System.out.print(Thread.currentThread().getName() + ": ");
@@ -569,5 +581,4 @@ public class EPPSessionTst extends TestCase {
 		System.out.println("\n");
 	}
 
-
-} // End class EPPSessionTst
+}
