@@ -116,7 +116,7 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	final static String ELM_ONLY_DNS_CHARS = "registry:onlyDnsChars";
 
 	/** XML tag name for the <code>regex</code> attribute. */
-	final static String ELM_REGEX = "registry:regex";
+	final static String ELM_REGEX = "regex";
 
 	/** XML attribute name for the <code>level</code> attribute. */
 	final static String ATTR_LEVEL = "level";
@@ -577,4 +577,15 @@ public class EPPRegistryDomainName implements EPPCodecComponent {
 	public void setReservedNames(EPPRegistryReservedNames reservedNames) {
 		this.reservedNames = reservedNames;
 	}
+	
+	/**
+	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+	 * 
+	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+	 */
+	@Override
+	public String getNamespace() {
+		return EPPRegistryMapFactory.NS;
+	}
+	
 }
