@@ -1,3 +1,23 @@
+/***********************************************************
+Copyright (C) 2013 VeriSign, Inc.
+
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+
+http://www.verisign.com/nds/naming/namestore/techdocs.html
+ ***********************************************************/
+
 package com.verisign.epp.interfaces;
 
 import java.security.SecureRandom;
@@ -40,15 +60,14 @@ public class EPPRegistryTst extends TestCase {
 	 * Handle to the Singleton EPP Application instance (
 	 * <code>EPPApplicationSingle</code>)
 	 */
-	private static EPPApplicationSingle app = EPPApplicationSingle
-			.getInstance();
+	private static EPPApplicationSingle app = EPPApplicationSingle.getInstance();
 
 	/** Name of configuration file to use for test (default = epp.config). */
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat = Logger.getLogger(EPPRegistryTst.class
-			.getName(), EPPCatFactory.getInstance().getFactory());
+	private static final Logger cat = Logger.getLogger(EPPRegistryTst.class.getName(),
+	      EPPCatFactory.getInstance().getFactory());
 
 	/** EPP Registry associated with test */
 	private EPPRegistry registry = null;
@@ -63,8 +82,8 @@ public class EPPRegistryTst extends TestCase {
 	private int iteration = 0;
 
 	/**
-	 * Random instance for the generation of unique objects (hosts, IP
-	 * addresses, etc.).
+	 * Random instance for the generation of unique objects (hosts, IP addresses,
+	 * etc.).
 	 */
 	private Random rd = new SecureRandom();
 
@@ -74,7 +93,7 @@ public class EPPRegistryTst extends TestCase {
 	 * logical name.
 	 * 
 	 * @param name
-	 *            Logical name of the test
+	 *           Logical name of the test
 	 */
 	public EPPRegistryTst(String name) {
 		super(name);
@@ -89,7 +108,8 @@ public class EPPRegistryTst extends TestCase {
 			try {
 				numIterations = Integer.parseInt(iterationsStr);
 				numIterations = (numIterations < 1) ? 1 : numIterations;
-			} catch (Exception e) {
+			}
+			catch (Exception e) {
 				numIterations = 1;
 			}
 		}
@@ -138,8 +158,7 @@ public class EPPRegistryTst extends TestCase {
 
 		EPPRegistryCheckResp response;
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 			System.out.print("registryCheck:");
 			registry.resetRegistry();
 			registry.setTransId("ABC-12345-XYZ");
@@ -153,32 +172,29 @@ public class EPPRegistryTst extends TestCase {
 
 			response = registry.sendCheck();
 
-			System.out.println("registryCheck: Response = [" + response
-					+ "]\n\n");
+			System.out.println("registryCheck: Response = [" + response + "]\n\n");
 
 			for (Iterator it = tldNames.entrySet().iterator(); it.hasNext();) {
 				Entry entry = (Entry) it.next();
 				String name = (String) entry.getKey();
 				Boolean available = (Boolean) entry.getValue();
-				inner: for (Iterator itt = response.getCheckResults()
-						.iterator(); itt.hasNext();) {
-					EPPRegistryCheckResult result = (EPPRegistryCheckResult) itt
-							.next();
+				inner: for (Iterator itt = response.getCheckResults().iterator(); itt.hasNext();) {
+					EPPRegistryCheckResult result = (EPPRegistryCheckResult) itt.next();
 					if (result.getName().equals(name)) {
-						if (result.isAvailable().booleanValue() == available
-								.booleanValue()) {
+						if (result.isAvailable().booleanValue() == available.booleanValue()) {
 							break inner;
-						} else {
-							fail("Expected availability for tld \"" + name
-									+ "\": " + available.booleanValue()
-									+ ", but got: " + result.isAvailable());
+						}
+						else {
+							fail("Expected availability for tld \"" + name + "\": " + available.booleanValue() + ", but got: "
+							      + result.isAvailable());
 						}
 					}
 				}
 			}
 
 			assertTrue(response != null && response.isSuccess());
-		} catch (EPPCommandException e) {
+		}
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -193,8 +209,7 @@ public class EPPRegistryTst extends TestCase {
 
 		EPPRegistryCreateResp response = null;
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 			System.out.println("registryCreate: " + tldName);
 			registry.resetRegistry();
 			registry.setTransId("ABC-12345-XYZ");
@@ -202,15 +217,16 @@ public class EPPRegistryTst extends TestCase {
 			registry.setAuthString("ClientX");
 
 			response = registry.sendCreate();
-			System.out.println("registryCreate: Response = [" + response
-					+ "]\n\n");
+			System.out.println("registryCreate: Response = [" + response + "]\n\n");
 
 			if (shouldSucceed) {
 				assertTrue(response != null && response.isSuccess());
-			} else {
+			}
+			else {
 				fail("Expecting error in response");
 			}
-		} catch (EPPCommandException e) {
+		}
+		catch (EPPCommandException e) {
 			if (shouldSucceed) {
 				handleException(e);
 			}
@@ -227,8 +243,7 @@ public class EPPRegistryTst extends TestCase {
 
 		EPPResponse response = null;
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 			System.out.println("registryDelete: " + tldName);
 			registry.resetRegistry();
 			registry.setTransId("ABC-12345-XYZ");
@@ -236,15 +251,16 @@ public class EPPRegistryTst extends TestCase {
 			registry.setAuthString("ClientX");
 
 			response = registry.sendDelete();
-			System.out.println("registryDelete: Response = [" + response
-					+ "]\n\n");
+			System.out.println("registryDelete: Response = [" + response + "]\n\n");
 
 			if (shouldSucceed) {
 				assertTrue(response != null && response.isSuccess());
-			} else {
+			}
+			else {
 				fail("Expecting error in response");
 			}
-		} catch (EPPCommandException e) {
+		}
+		catch (EPPCommandException e) {
 			if (shouldSucceed) {
 				handleException(e);
 			}
@@ -261,8 +277,7 @@ public class EPPRegistryTst extends TestCase {
 
 		EPPResponse response = null;
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 			System.out.println("registryUpdate: " + tldName);
 			registry.resetRegistry();
 			registry.setTransId("ABC-12345-XYZ");
@@ -270,15 +285,16 @@ public class EPPRegistryTst extends TestCase {
 			registry.setAuthString("ClientX");
 
 			response = registry.sendUpdate();
-			System.out.println("registryUpdate: Response = [" + response
-					+ "]\n\n");
+			System.out.println("registryUpdate: Response = [" + response + "]\n\n");
 
 			if (shouldSucceed) {
 				assertTrue(response != null && response.isSuccess());
-			} else {
+			}
+			else {
 				fail("Expecting error in response");
 			}
-		} catch (EPPCommandException e) {
+		}
+		catch (EPPCommandException e) {
 			if (shouldSucceed) {
 				handleException(e);
 			}
@@ -300,51 +316,46 @@ public class EPPRegistryTst extends TestCase {
 
 		EPPRegistryInfoResp response;
 		try {
-			System.out
-					.println("\n----------------------------------------------------------------");
+			System.out.println("\n----------------------------------------------------------------");
 			if (all) {
 				System.out.println("registryInfo: all tlds");
-			} else {
+			}
+			else {
 				System.out.println("registryInfo: single tld");
 			}
 
 			registry.setTransId("ABC-12345-XYZ");
 			if (all) {
 				registry.setAllTlds(true);
-			} else {
+			}
+			else {
 				System.out.println("\nregistryInfo: " + tldName);
 				registry.addTld(tldName);
 			}
 
 			response = registry.sendInfo();
 
-			System.out.println("registryInfo: Response = [" + response
-					+ "]\n\n");
+			System.out.println("registryInfo: Response = [" + response + "]\n\n");
 
 			if (all) {
-				assertTrue(response.getZoneList() != null
-						&& response.getZoneList().getZoneList() != null
-						&& response.getZoneInfo() == null
-						&& response.getZoneList().getZoneList().size() > 0);
+				assertTrue(response.getZoneList() != null && response.getZoneList().getZoneList() != null
+				      && response.getZoneInfo() == null && response.getZoneList().getZoneList().size() > 0);
 				System.out.println("All TLDs: ");
-				for (Iterator it = response.getZoneList().getZoneList()
-						.iterator(); it.hasNext();) {
+				for (Iterator it = response.getZoneList().getZoneList().iterator(); it.hasNext();) {
 					EPPRegistryZone tld = (EPPRegistryZone) it.next();
-					assertTrue(tld.getName() != null
-							&& tld.getName().length() > 0);
+					assertTrue(tld.getName() != null && tld.getName().length() > 0);
 					assertTrue(tld.getCreateDate() != null);
-					System.out.print(tld.getName() + "\tcreated on "
-							+ tld.getCreateDate());
+					System.out.print(tld.getName() + "\tcreated on " + tld.getCreateDate());
 					if (tld.getUpdateDate() != null) {
-						System.out.println("\tupdated on "
-								+ tld.getUpdateDate());
-					} else {
+						System.out.println("\tupdated on " + tld.getUpdateDate());
+					}
+					else {
 						System.out.println();
 					}
 				}
-			} else {
-				assertTrue(response.getZoneList() == null
-						&& response.getZoneInfo() != null);
+			}
+			else {
+				assertTrue(response.getZoneList() == null && response.getZoneInfo() != null);
 				EPPRegistryZoneInfo info = response.getZoneInfo();
 				System.out.println("Zone name: " + info.getName());
 				if (info.hasRelated()) {
@@ -352,50 +363,38 @@ public class EPPRegistryTst extends TestCase {
 					EPPRegistryRelated related = info.getRelated();
 					if (related.hasFields()) {
 						EPPRegistryFields fields = related.getFields();
-						
+
 						System.out.println("\ttype:" + fields.getType());
 						for (Iterator it = fields.getFields().iterator(); it.hasNext();) {
-							System.out.println("\tfield: " + (String) it.next());							
+							System.out.println("\tfield: " + (String) it.next());
 						}
 					}
-						System.out.println("\tMembers:");
-					for (Iterator it = info.getRelated().getMembers().iterator(); it
-							.hasNext();) {
-						EPPRegistryZoneMember member = (EPPRegistryZoneMember) it
-								.next();
-						System.out.println("\t\tname: " + member.getZoneName()
-								+ ", type: " + member.getType());
+					System.out.println("\tMembers:");
+					for (Iterator it = info.getRelated().getMembers().iterator(); it.hasNext();) {
+						EPPRegistryZoneMember member = (EPPRegistryZoneMember) it.next();
+						System.out.println("\t\tname: " + member.getZoneName() + ", type: " + member.getType());
 					}
 				}
 				if (info.getPhases() != null) {
 					System.out.println("Phases:");
-					for (Iterator it = info.getPhases().iterator(); it
-							.hasNext();) {
+					for (Iterator it = info.getPhases().iterator(); it.hasNext();) {
 						EPPRegistryPhase phase = (EPPRegistryPhase) it.next();
-						System.out.println("\ttype: " + phase.getType()
-								+ ", start: " + phase.getStartDate()
-								+ ", end: " + phase.getEndDate());
+						System.out.println("\ttype: " + phase.getType() + ", start: " + phase.getStartDate() + ", end: "
+						      + phase.getEndDate());
 					}
 				}
 				if (info.getServices() != null) {
 					System.out.println("Services:");
-					for (Iterator it = info.getServices().getObjURIs()
-							.iterator(); it.hasNext();) {
-						EPPRegistryObjURI objUri = (EPPRegistryObjURI) it
-								.next();
-						System.out.println("\tobjURI: " + objUri.getUri()
-								+ ", required: " + objUri.getRequired());
+					for (Iterator it = info.getServices().getObjURIs().iterator(); it.hasNext();) {
+						EPPRegistryObjURI objUri = (EPPRegistryObjURI) it.next();
+						System.out.println("\tobjURI: " + objUri.getUri() + ", required: " + objUri.getRequired());
 					}
 				}
-				if (info.getServices() != null
-						&& info.getServices().getExtension() != null) {
+				if (info.getServices() != null && info.getServices().getExtension() != null) {
 					System.out.println("Services extension:");
-					for (Iterator it = info.getServices().getExtension()
-							.getExtURIs().iterator(); it.hasNext();) {
-						EPPRegistryExtURI extUri = (EPPRegistryExtURI) it
-								.next();
-						System.out.println("\textURI: " + extUri.getUri()
-								+ ", required: " + extUri.getRequired());
+					for (Iterator it = info.getServices().getExtension().getExtURIs().iterator(); it.hasNext();) {
+						EPPRegistryExtURI extUri = (EPPRegistryExtURI) it.next();
+						System.out.println("\textURI: " + extUri.getUri() + ", required: " + extUri.getRequired());
 					}
 				}
 				System.out.println("crId: " + info.getCreatedBy());
@@ -415,7 +414,8 @@ public class EPPRegistryTst extends TestCase {
 			assertTrue(response != null && response.isSuccess());
 
 			printEnd("registryInfo");
-		} catch (EPPCommandException e) {
+		}
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 	}
@@ -437,7 +437,7 @@ public class EPPRegistryTst extends TestCase {
 	 * :&lt;Exception Description&gt;" will be specified.
 	 * 
 	 * @param aException
-	 *            Exception thrown during test
+	 *           Exception thrown during test
 	 */
 	public void handleException(Exception aException) {
 		EPPResponse theResponse = null;
@@ -486,23 +486,21 @@ public class EPPRegistryTst extends TestCase {
 					Class theSessionClass = Class.forName(theSessionClassName);
 
 					if (!EPPSession.class.isAssignableFrom((theSessionClass))) {
-						Assert.fail(theSessionClassName
-								+ " is not a subclass of EPPSession");
+						Assert.fail(theSessionClassName + " is not a subclass of EPPSession");
 					}
 
-					session = (EPPSession) theSessionClass.newInstance();
-				} catch (Exception ex) {
-					Assert.fail("Exception instantiating EPP.SessionClass value "
-							+ theSessionClassName + ": " + ex);
+					session = (EPPSession) theSessionClass.getDeclaredConstructor().newInstance();
 				}
-			} else {
+				catch (Exception ex) {
+					Assert.fail("Exception instantiating EPP.SessionClass value " + theSessionClassName + ": " + ex);
+				}
+			}
+			else {
 				session = new EPPSession();
 			}
 
-			session.setClientID(Environment.getProperty("EPP.Test.clientId",
-					"ClientX"));
-			session.setPassword(Environment.getProperty("EPP.Test.password",
-					"foo-BAR2"));
+			session.setClientID(Environment.getProperty("EPP.Test.clientId", "ClientX"));
+			session.setPassword(Environment.getProperty("EPP.Test.password", "foo-BAR2"));
 		}
 
 		catch (Exception e) {
@@ -525,8 +523,8 @@ public class EPPRegistryTst extends TestCase {
 	}
 
 	/**
-	 * Unit test of <code>EPPSession.initSession</code>. The session attribute
-	 * is initialized with the attributes defined in the EPP sample files.
+	 * Unit test of <code>EPPSession.initSession</code>. The session attribute is
+	 * initialized with the attributes defined in the EPP sample files.
 	 */
 	private void initSession() {
 		printStart("initSession");
@@ -549,7 +547,8 @@ public class EPPRegistryTst extends TestCase {
 			// Is a server specified error?
 			if ((response != null) && (!response.isSuccess())) {
 				Assert.fail("Server Error : " + response);
-			} else {
+			}
+			else {
 				e.printStackTrace();
 
 				Assert.fail("initSession Error : " + e);
@@ -593,25 +592,22 @@ public class EPPRegistryTst extends TestCase {
 	}
 
 	/**
-	 * Print the start of a test with the <code>Thread</code> name if the
-	 * current thread is a <code>TestThread</code>.
+	 * Print the start of a test with the <code>Thread</code> name if the current
+	 * thread is a <code>TestThread</code>.
 	 * 
 	 * @param aTest
-	 *            name for the test
+	 *           name for the test
 	 */
 	private void printStart(String aTest) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": ");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
 
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aTest + " Start");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " Start");
 		}
 
 		System.out.println("Start of " + aTest);
 
-		System.out
-				.println("****************************************************************\n");
+		System.out.println("****************************************************************\n");
 	}
 
 	/**
@@ -619,18 +615,15 @@ public class EPPRegistryTst extends TestCase {
 	 * thread is a <code>TestThread</code>.
 	 * 
 	 * @param aTest
-	 *            name for the test
+	 *           name for the test
 	 */
 	private void printEnd(String aTest) {
-		System.out
-				.println("****************************************************************");
+		System.out.println("****************************************************************");
 
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": ");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
 
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					+ iteration + ": " + aTest + " End");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " End");
 		}
 
 		System.out.println("End of " + aTest);
