@@ -259,6 +259,9 @@ public class RegistryHandler extends EPPRegistryHandler {
 				}
 			}
 		}
+		
+		// Process policy extensions
+		
 
 		cat.debug("doRegistryCreate: exit");
 		return new EPPEventResponse(theResponse);
@@ -471,12 +474,12 @@ public class RegistryHandler extends EPPRegistryHandler {
 
 		List domainNames = new ArrayList();
 		EPPRegistryDomainName domainName = new EPPRegistryDomainName();
-		domainName.setLevel(new Integer(2));
-		domainName.setMinLength(new Integer(5));
-		domainName.setMaxLength(new Integer(50));
-		domainName.setAlphaNumStart(new Boolean(true));
-		domainName.setAlphaNumEnd(new Boolean(false));
-		domainName.setOnlyDnsChars(new Boolean(true));
+		domainName.setLevel(Integer.valueOf(2));
+		domainName.setMinLength(Integer.valueOf(5));
+		domainName.setMaxLength(Integer.valueOf(50));
+		domainName.setAlphaNumStart(Boolean.valueOf(true));
+		domainName.setAlphaNumEnd(Boolean.valueOf(false));
+		domainName.setOnlyDnsChars(Boolean.valueOf(true));
 
 		List regex = new ArrayList();
 		EPPRegistryRegex r = new EPPRegistryRegex("^\\w+.*$", "test regex");
@@ -498,7 +501,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 
 		try {
 			domainName = (EPPRegistryDomainName) domainName.clone();
-			domainName.setLevel(new Integer(3));
+			domainName.setLevel(Integer.valueOf(3));
 			domainName.getReservedNames().setReservedNames(new ArrayList());
 			domainName.getReservedNames().setReservedNameURI(
 					"http://testrn.vrsn.com");
@@ -523,8 +526,8 @@ public class RegistryHandler extends EPPRegistryHandler {
 		idn.setCommingleAllowed(Boolean.TRUE);
 		domain.setIdn(idn);
 
-		domain.setPremiumSupport(new Boolean(true));
-		domain.setContactsSupported(new Boolean(true));
+		domain.setPremiumSupport(Boolean.valueOf(true));
+		domain.setContactsSupported(Boolean.valueOf(true));
 
 		domain.addContact(new EPPRegistryDomainContact(
 				EPPRegistryDomainContact.TYPE_ADMIN, 1, 4));
@@ -579,7 +582,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 		dnssec.setUrgent(Boolean.TRUE);
 
 		domain.setDnssec(dnssec);
-		domain.setMaxCheckDomain(new Integer(12));
+		domain.setMaxCheckDomain(Integer.valueOf(12));
 		domain.setAuthInfoRegex(new EPPRegistryRegex("^.*$", "exp"));
 
 		EPPRegistryCustomData customData = new EPPRegistryCustomData();
@@ -621,7 +624,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 				EPPRegistryExternalHost.TYPE_PER_ZONE));
 		host.addNameRegex(new EPPRegistryRegex("^.*$", "exp" + seq + "1"));
 		host.addNameRegex(new EPPRegistryRegex("^.*$", "exp" + seq + "2"));
-		host.setMaxCheckHost(new Integer(15));
+		host.setMaxCheckHost(Integer.valueOf(15));
 
 		EPPRegistryCustomData customData = new EPPRegistryCustomData();
 		customData.addKeyValue(new EPPRegistryKeyValue("hk" + seq + "1", "hv"
@@ -663,7 +666,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 
 		contact.setAuthInfoRegex(new EPPRegistryRegex("^.*$", "exp"));
 
-		contact.setMaxCheckContact(new Integer(15));
+		contact.setMaxCheckContact(Integer.valueOf(15));
 
 		EPPRegistryPostal postalInfo = new EPPRegistryPostal();
 		postalInfo.setName(new EPPRegistryContactName(6, 16));
@@ -684,7 +687,7 @@ public class RegistryHandler extends EPPRegistryHandler {
 
 		postalInfo.setAddress(address);
 
-		contact.setMaxCheckContact(new Integer(5));
+		contact.setMaxCheckContact(Integer.valueOf(5));
 
 		contact.setPostalInfo(postalInfo);
 
