@@ -19,7 +19,6 @@ http://www.verisign.com/nds/naming/namestore/techdocs.html
 ***********************************************************/
 package com.verisign.epp.interfaces;
 
-
 // JUNIT Imports
 import java.util.Date;
 import java.util.List;
@@ -47,41 +46,40 @@ import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.Environment;
 import com.verisign.epp.util.TestThread;
 
-
 /**
- * Is a unit test of the <code>EPPDomain</code> class with RGP update,
- * inf data and report extensions.
+ * Is a unit test of the <code>EPPDomain</code> class with RGP update, inf data
+ * and report extensions.
  *
- * The unit test will
- * initialize a session with an EPP Server, will invoke <code>EPPDomain</code>
- * operations, and will end a session with an EPP Server. The configuration
- * file used by the unit test defaults to epp.config, but can be changed by
- * passing the file path as the first command line argument. The unit test can
- * be run in multiple threads by setting the "threads" system property. For
- * example, the unit test can be run in 2 threads with the configuration file
- * ../../epp.config with the following command: <br>
+ * The unit test will initialize a session with an EPP Server, will invoke
+ * <code>EPPDomain</code> operations, and will end a session with an EPP Server.
+ * The configuration file used by the unit test defaults to epp.config, but can
+ * be changed by passing the file path as the first command line argument. The
+ * unit test can be run in multiple threads by setting the "threads" system
+ * property. For example, the unit test can be run in 2 threads with the
+ * configuration file ../../epp.config with the following command: <br>
+ * <br>
+ * java com.verisign.epp.interfaces.EPPRgpDomainTst -Dthreads=2 ../../epp.config
  * <br>
- * java com.verisign.epp.interfaces.EPPRgpDomainTst -Dthreads=2 ../../epp.config <br>
  * <br>
  * The unit test is dependent on the use of <a
- * href=http://www.mcwestcorp.com/Junit.html>JUNIT 3.5</a><br><br><br><br>
+ * href=http://www.mcwestcorp.com/Junit.html>JUNIT 3.5</a><br>
+ * <br>
+ * <br>
+ * <br>
  */
 public class EPPRgpDomainTst extends TestCase {
 	/**
 	 * Handle to the Singleton EPP Application instance
 	 * (<code>EPPApplicationSingle</code>)
 	 */
-	private static EPPApplicationSingle app =
-		EPPApplicationSingle.getInstance();
+	private static EPPApplicationSingle app = EPPApplicationSingle.getInstance();
 
 	/** Name of configuration file to use for test (default = epp.config). */
 	private static String configFileName = "epp.config";
 
 	/** Logging category */
-	private static final Logger cat =
-		Logger.getLogger(
-						 EPPRgpDomainTst.class.getName(),
-						 EPPCatFactory.getInstance().getFactory());
+	private static final Logger cat = Logger.getLogger(EPPRgpDomainTst.class.getName(),
+	      EPPCatFactory.getInstance().getFactory());
 
 	/** EPP Domain associated with test */
 	private EPPDomain domain = null;
@@ -96,17 +94,18 @@ public class EPPRgpDomainTst extends TestCase {
 	private int iteration = 0;
 
 	/**
-	 * Random instance for the generation of unique objects (hosts, IP
-	 * addresses, etc.).
+	 * Random instance for the generation of unique objects (hosts, IP addresses,
+	 * etc.).
 	 */
 	private Random rd = new Random(System.currentTimeMillis());
 
 	/**
 	 * Allocates an <code>EPPRgpDomainTst</code> with a logical name. The
-	 * constructor will initialize the base class <code>TestCase</code> with
-	 * the logical name.
+	 * constructor will initialize the base class <code>TestCase</code> with the
+	 * logical name.
 	 *
-	 * @param name Logical name of the test
+	 * @param name
+	 *           Logical name of the test
 	 */
 	public EPPRgpDomainTst(String name) {
 		super(name);
@@ -120,7 +119,7 @@ public class EPPRgpDomainTst extends TestCase {
 	 * interface.
 	 */
 	public void testDomain() {
-		int    numIterations = 1;
+		int numIterations = 1;
 
 		String iterationsStr = System.getProperty("iterations");
 
@@ -128,17 +127,14 @@ public class EPPRgpDomainTst extends TestCase {
 			numIterations = Integer.parseInt(iterationsStr);
 		}
 
-		for (
-			 iteration = 0;
-				 (numIterations == 0) || (iteration < numIterations);
-				 iteration++) {
+		for (iteration = 0; (numIterations == 0) || (iteration < numIterations); iteration++) {
 			printStart("Test Suite");
 
 			domainRestoreRequest();
 
 			domainRestoreReport();
 
-            domainInfo();
+			domainInfo();
 
 			domainPoll();
 
@@ -165,39 +161,34 @@ public class EPPRgpDomainTst extends TestCase {
 
 			response = domain.sendInfo();
 
-			//-- Output all of the response attributes
+			// -- Output all of the response attributes
 			System.out.println("domainInfo: Response = [" + response + "]\n\n");
 
-			//-- Output required response attributes using accessors
+			// -- Output required response attributes using accessors
 			System.out.println("domainInfo: name = " + response.getName());
 
-			System.out.println("domainInfo: client id = "
-							   + response.getClientId());
+			System.out.println("domainInfo: client id = " + response.getClientId());
 
-			System.out.println("domainInfo: created by = "
-							   + response.getCreatedBy());
+			System.out.println("domainInfo: created by = " + response.getCreatedBy());
 
-			System.out.println("domainInfo: create date = "
-							   + response.getCreatedDate());
+			System.out.println("domainInfo: create date = " + response.getCreatedDate());
 
-			System.out.println("domainInfo: expiration date = "
-							   + response.getExpirationDate());
+			System.out.println("domainInfo: expiration date = " + response.getExpirationDate());
 
 			this.printRgpStatuses(response);
 
-			domain.setTransId( "ABC-12345-XYZ" );
+			domain.setTransId("ABC-12345-XYZ");
 
-			domain.addDomainName( "graceperiod.com" );
+			domain.addDomainName("graceperiod.com");
 			response = domain.sendInfo();
 
 			// -- Output all of the response attributes
-			System.out.println( "domainInfo: Response for graceperiod.com = ["
-					+ response + "]\n\n" );
-			
+			System.out.println("domainInfo: Response for graceperiod.com = [" + response + "]\n\n");
+
 			this.printRgpStatuses(response);
 
 		}
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -206,9 +197,9 @@ public class EPPRgpDomainTst extends TestCase {
 
 	// End EPPRgpDomainTst.domainInfo()
 
-
 	/**
-	 * Unit test of <code>EPPDomain.sendUpdate</code> with RGP restore request extension.
+	 * Unit test of <code>EPPDomain.sendUpdate</code> with RGP restore request
+	 * extension.
 	 */
 	public void domainRestoreRequest() {
 		printStart("domainRestoreRequest");
@@ -222,21 +213,19 @@ public class EPPRgpDomainTst extends TestCase {
 
 			domain.addDomainName(myDomainName);
 
-           domain.addExtension(new EPPRgpExtUpdate(new EPPRgpExtRestore()));
+			domain.addExtension(new EPPRgpExtUpdate(new EPPRgpExtRestore()));
 
 			// Execute update
 			response = domain.sendUpdate();
 
-			//-- Output all of the response attributes
-			System.out.println("domainRestoreRequest: Response = [" + response
-							   + "]\n\n");
+			// -- Output all of the response attributes
+			System.out.println("domainRestoreRequest: Response = [" + response + "]\n\n");
 
 			/**
 			 * Result Set
 			 */
 			for (int i = 0; i < response.getResults().size(); i++) {
-				EPPResult myResult =
-					(EPPResult) response.getResults().elementAt(i);
+				EPPResult myResult = (EPPResult) response.getResults().elementAt(i);
 
 				System.out.println("Result Code    : " + myResult.getCode());
 
@@ -254,14 +243,13 @@ public class EPPRgpDomainTst extends TestCase {
 
 				if (myResult.getAllValues() != null) {
 					for (int k = 0; k < myResult.getAllValues().size(); k++) {
-						System.out.println("Result Values  : "
-										   + myResult.getAllValues().elementAt(k));
+						System.out.println("Result Values  : " + myResult.getAllValues().elementAt(k));
 					}
 				}
 			}
 		}
 
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -270,9 +258,9 @@ public class EPPRgpDomainTst extends TestCase {
 
 	// End EPPRgpDomainTst.domainRestoreRequest()
 
-
 	/**
-	 * Unit test of <code>EPPDomain.sendUpdate</code> with RGP restore request extension.
+	 * Unit test of <code>EPPDomain.sendUpdate</code> with RGP restore request
+	 * extension.
 	 */
 	public void domainRestoreReport() {
 		printStart("domainRestoreReport");
@@ -286,48 +274,40 @@ public class EPPRgpDomainTst extends TestCase {
 
 			domain.addDomainName(myDomainName);
 
+			EPPRgpExtReport report = new EPPRgpExtReport();
+			report.setPreData("Pre-delete whois data goes here. Both XML and free text are allowed");
+			report.setPostData("Post-delete whois data goes here. Both XML and free text are allowed");
+			report.setDeleteTime(new Date());
+			report.setRestoreTime(new Date());
 
- 
-              EPPRgpExtReport report = new EPPRgpExtReport();
-              report.setPreData("Pre-delete whois data goes here. Both XML and free text are allowed");
-              report.setPostData("Post-delete whois data goes here. Both XML and free text are allowed");
-              report.setDeleteTime(new Date());
-              report.setRestoreTime(new Date());
+			report.setRestoreReason(new EPPRgpExtReportText("Registrant Error"));
 
-              report.setRestoreReason(new EPPRgpExtReportText("Registrant Error"));
+			report.setStatement1(
+			      new EPPRgpExtReportText("This registrar has not" + " restored the Registered Domain in order to "
+			            + "assume the rights to use or sell the Registered" + " Name for itself or for any third party"));
 
-              report.setStatement1(new EPPRgpExtReportText("This registrar has not" +
-                  " restored the Registered Domain in order to " +
-                  "assume the rights to use or sell the Registered" +
-                  " Name for itself or for any third party"));
+			report.setStatement2(new EPPRgpExtReportText("The information in this report "
+			      + " is true to best of this registrar's knowledge, and this"
+			      + "registrar acknowledges that intentionally supplying false" + " information in this report shall "
+			      + "constitute  an incurable material breach of the Registry-Registrar" + " Agreement"));
 
-              report.setStatement2(new EPPRgpExtReportText("The information in this report " +
-                  " is true to best of this registrar's knowledge, and this" +
-                  "registrar acknowledges that intentionally supplying false" +
-                  " information in this report shall " +
-                  "constitute  an incurable material breach of the Registry-Registrar" +
-                  " Agreement"));
+			report.setOther("other stuff");
 
-              report.setOther("other stuff");
-
-              EPPRgpExtRestore restore = new EPPRgpExtRestore(report);
-          
-              domain.addExtension(new EPPRgpExtUpdate(restore));
+			EPPRgpExtRestore restore = new EPPRgpExtRestore(report);
 
+			domain.addExtension(new EPPRgpExtUpdate(restore));
 
 			// Execute update
 			response = domain.sendUpdate();
 
-			//-- Output all of the response attributes
-			System.out.println("domainRestoreReport: Response = [" + response
-							   + "]\n\n");
+			// -- Output all of the response attributes
+			System.out.println("domainRestoreReport: Response = [" + response + "]\n\n");
 
 			/**
 			 * Result Set
 			 */
 			for (int i = 0; i < response.getResults().size(); i++) {
-				EPPResult myResult =
-					(EPPResult) response.getResults().elementAt(i);
+				EPPResult myResult = (EPPResult) response.getResults().elementAt(i);
 
 				System.out.println("Result Code    : " + myResult.getCode());
 
@@ -345,14 +325,13 @@ public class EPPRgpDomainTst extends TestCase {
 
 				if (myResult.getAllValues() != null) {
 					for (int k = 0; k < myResult.getAllValues().size(); k++) {
-						System.out.println("Result Values  : "
-										   + myResult.getAllValues().elementAt(k));
+						System.out.println("Result Values  : " + myResult.getAllValues().elementAt(k));
 					}
 				}
 			}
 		}
 
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			handleException(e);
 		}
 
@@ -360,8 +339,7 @@ public class EPPRgpDomainTst extends TestCase {
 	}
 
 	// End EPPRgpDomainTst.domainRestoreReport()
-	
-	
+
 	/**
 	 * Unit test of <code>EPPDomain.sendPoll</code>.
 	 */
@@ -392,17 +370,16 @@ public class EPPRgpDomainTst extends TestCase {
 			System.out.println("domainPoll: Response = [" + response + "]\n\n");
 		}
 
-		 catch (EPPCommandException ex) {
+		catch (EPPCommandException ex) {
 			handleException(ex);
 		}
 
 		printEnd("domainPoll");
 	}
 
-
 	/**
-	 * Unit test of <code>EPPSession.initSession</code>. The session attribute
-	 * is initialized with the attributes defined in the EPP sample files.
+	 * Unit test of <code>EPPSession.initSession</code>. The session attribute is
+	 * initialized with the attributes defined in the EPP sample files.
 	 */
 	private void initSession() {
 		printStart("initSession");
@@ -419,7 +396,7 @@ public class EPPRgpDomainTst extends TestCase {
 			session.initSession();
 		}
 
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			EPPResponse response = session.getResponse();
 
 			// Is a server specified error?
@@ -439,8 +416,8 @@ public class EPPRgpDomainTst extends TestCase {
 	// End EPPRgpDomainTst.initSession()
 
 	/**
-	 * Unit test of <code>EPPSession.endSession</code>. The session with the
-	 * EPP Server will be terminated.
+	 * Unit test of <code>EPPSession.endSession</code>. The session with the EPP
+	 * Server will be terminated.
 	 */
 	private void endSession() {
 		printStart("endSession");
@@ -452,7 +429,7 @@ public class EPPRgpDomainTst extends TestCase {
 			session.endSession();
 		}
 
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			EPPResponse response = session.getResponse();
 
 			// Is a server specified error?
@@ -461,7 +438,7 @@ public class EPPRgpDomainTst extends TestCase {
 			}
 
 			else // Other error
-			 {
+			{
 				e.printStackTrace();
 
 				Assert.fail("initSession Error : " + e);
@@ -486,15 +463,13 @@ public class EPPRgpDomainTst extends TestCase {
 					Class theSessionClass = Class.forName(theSessionClassName);
 
 					if (!EPPSession.class.isAssignableFrom((theSessionClass))) {
-						Assert.fail(theSessionClassName
-									+ " is not a subclass of EPPSession");
+						Assert.fail(theSessionClassName + " is not a subclass of EPPSession");
 					}
 
-					session = (EPPSession) theSessionClass.newInstance();
+					session = (EPPSession) theSessionClass.getDeclaredConstructor().newInstance();
 				}
-				 catch (Exception ex) {
-					Assert.fail("Exception instantiating EPP.SessionClass value "
-								+ theSessionClassName + ": " + ex);
+				catch (Exception ex) {
+					Assert.fail("Exception instantiating EPP.SessionClass value " + theSessionClassName + ": " + ex);
 				}
 			}
 			else {
@@ -505,7 +480,7 @@ public class EPPRgpDomainTst extends TestCase {
 			session.setPassword(Environment.getProperty("EPP.Test.password", "foo-BAR2"));
 		}
 
-		 catch (Exception e) {
+		catch (Exception e) {
 			e.printStackTrace();
 
 			Assert.fail("Error initializing the session: " + e);
@@ -513,7 +488,7 @@ public class EPPRgpDomainTst extends TestCase {
 
 		initSession();
 
-		//System.out.println("out init");
+		// System.out.println("out init");
 		domain = new EPPDomain(session);
 	}
 
@@ -529,8 +504,8 @@ public class EPPRgpDomainTst extends TestCase {
 	// End EPPRgpDomainTst.tearDown();
 
 	/**
-	 * JUNIT <code>suite</code> static method, which returns the tests
-	 * associated with <code>EPPRgpDomainTst</code>.
+	 * JUNIT <code>suite</code> static method, which returns the tests associated
+	 * with <code>EPPRgpDomainTst</code>.
 	 *
 	 * @return DOCUMENT ME!
 	 */
@@ -545,7 +520,7 @@ public class EPPRgpDomainTst extends TestCase {
 			app.initialize(configFileName);
 		}
 
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			e.printStackTrace();
 
 			Assert.fail("Error initializing the EPP Application: " + e);
@@ -558,12 +533,13 @@ public class EPPRgpDomainTst extends TestCase {
 
 	/**
 	 * Handle an <code>EPPCommandException</code>, which can be either a server
-	 * generated error or a general exception. If the exception was caused by
-	 * a server error, "Server Error :&lt;Response XML&gt;" will be specified.
-	 * If the exception was caused by a general algorithm error, "General
-	 * Error :&lt;Exception Description&gt;" will be specified.
+	 * generated error or a general exception. If the exception was caused by a
+	 * server error, "Server Error :&lt;Response XML&gt;" will be specified. If
+	 * the exception was caused by a general algorithm error, "General Error
+	 * :&lt;Exception Description&gt;" will be specified.
 	 *
-	 * @param aException Exception thrown during test
+	 * @param aException
+	 *           Exception thrown during test
 	 */
 	public void handleException(Exception aException) {
 		EPPResponse response = session.getResponse();
@@ -583,22 +559,18 @@ public class EPPRgpDomainTst extends TestCase {
 	// End EPPRgpDomainTst.handleException(EPPCommandException)
 
 	/**
-	 * Unit test main, which accepts the following system property options:
-	 * <br>
+	 * Unit test main, which accepts the following system property options: <br>
 	 *
 	 * <ul>
-	 * <li>
-	 * iterations Number of unit test iterations to run
-	 * </li>
-	 * <li>
-	 * validate Turn XML validation on (<code>true</code>) or off
+	 * <li>iterations Number of unit test iterations to run</li>
+	 * <li>validate Turn XML validation on (<code>true</code>) or off
 	 * (<code>false</code>). If validate is not specified, validation will be
-	 * off.
-	 * </li>
+	 * off.</li>
 	 * </ul>
 	 *
 	 *
-	 * @param args DOCUMENT ME!
+	 * @param args
+	 *           DOCUMENT ME!
 	 */
 	public static void main(String[] args) {
 		// Override the default configuration file name?
@@ -607,7 +579,7 @@ public class EPPRgpDomainTst extends TestCase {
 		}
 
 		// Number of Threads
-		int    numThreads = 1;
+		int numThreads = 1;
 
 		String threadsStr = System.getProperty("threads");
 
@@ -620,10 +592,7 @@ public class EPPRgpDomainTst extends TestCase {
 		if (numThreads > 1) {
 			// Spawn each thread passing in the Test Suite
 			for (int i = 0; i < numThreads; i++) {
-				TestThread thread =
-					new TestThread(
-								   "EPPSessionTst Thread " + i,
-								   EPPRgpDomainTst.suite());
+				TestThread thread = new TestThread("EPPSessionTst Thread " + i, EPPRgpDomainTst.suite());
 
 				thread.start();
 			}
@@ -637,7 +606,7 @@ public class EPPRgpDomainTst extends TestCase {
 			app.endApplication();
 		}
 
-		 catch (EPPCommandException e) {
+		catch (EPPCommandException e) {
 			e.printStackTrace();
 
 			Assert.fail("Error ending the EPP Application: " + e);
@@ -655,9 +624,7 @@ public class EPPRgpDomainTst extends TestCase {
 	public String makeDomainName() {
 		long tm = System.currentTimeMillis();
 
-		return new String(Thread.currentThread()
-						  + String.valueOf(tm + rd.nextInt(12)).substring(10)
-						  + ".com");
+		return new String(Thread.currentThread() + String.valueOf(tm + rd.nextInt(12)).substring(10) + ".com");
 	}
 
 	/**
@@ -668,27 +635,24 @@ public class EPPRgpDomainTst extends TestCase {
 	public String makeIP() {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(50)).substring(10)
-						  + "."
-						  + String.valueOf(tm + rd.nextInt(50)).substring(10)
-						  + "."
-						  + String.valueOf(tm + rd.nextInt(50)).substring(10)
-						  + "."
-						  + String.valueOf(tm + rd.nextInt(50)).substring(10));
+		return new String(
+		      String.valueOf(tm + rd.nextInt(50)).substring(10) + "." + String.valueOf(tm + rd.nextInt(50)).substring(10)
+		            + "." + String.valueOf(tm + rd.nextInt(50)).substring(10) + "."
+		            + String.valueOf(tm + rd.nextInt(50)).substring(10));
 	}
 
 	/**
 	 * Makes a unique host name for a domain using the current time.
 	 *
-	 * @param newDomainName DOCUMENT ME!
+	 * @param newDomainName
+	 *           DOCUMENT ME!
 	 *
 	 * @return Unique host name <code>String</code>
 	 */
 	public String makeHostName(String newDomainName) {
 		long tm = System.currentTimeMillis();
 
-		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10)
-						  + "." + newDomainName);
+		return new String(String.valueOf(tm + rd.nextInt(10)).substring(10) + "." + newDomainName);
 	}
 
 	/**
@@ -699,23 +663,21 @@ public class EPPRgpDomainTst extends TestCase {
 	public String makeContactName() {
 		long tm = System.currentTimeMillis();
 
-		return new String("Con"
-						  + String.valueOf(tm + rd.nextInt(5)).substring(7));
+		return new String("Con" + String.valueOf(tm + rd.nextInt(5)).substring(7));
 	}
 
 	/**
-	 * Print the start of a test with the <code>Thread</code> name if the
-	 * current thread is a <code>TestThread</code>.
+	 * Print the start of a test with the <code>Thread</code> name if the current
+	 * thread is a <code>TestThread</code>.
 	 *
-	 * @param aTest name for the test
+	 * @param aTest
+	 *           name for the test
 	 */
 	private void printStart(String aTest) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-							 + iteration + ": ");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
 
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					 + iteration + ": " + aTest + " Start");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " Start");
 		}
 
 		System.out.println("Start of " + aTest);
@@ -729,17 +691,16 @@ public class EPPRgpDomainTst extends TestCase {
 	 * Print the end of a test with the <code>Thread</code> name if the current
 	 * thread is a <code>TestThread</code>.
 	 *
-	 * @param aTest name for the test
+	 * @param aTest
+	 *           name for the test
 	 */
 	private void printEnd(String aTest) {
 		System.out.println("****************************************************************");
 
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.print(Thread.currentThread().getName() + ", iteration "
-							 + iteration + ": ");
+			System.out.print(Thread.currentThread().getName() + ", iteration " + iteration + ": ");
 
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					 + iteration + ": " + aTest + " End");
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aTest + " End");
 		}
 
 		System.out.println("End of " + aTest);
@@ -752,15 +713,14 @@ public class EPPRgpDomainTst extends TestCase {
 	/**
 	 * Print message
 	 *
-	 * @param aMsg message to print
+	 * @param aMsg
+	 *           message to print
 	 */
 	private void printMsg(String aMsg) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.out.println(Thread.currentThread().getName()
-							   + ", iteration " + iteration + ": " + aMsg);
+			System.out.println(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 
-			cat.info(Thread.currentThread().getName() + ", iteration "
-					 + iteration + ": " + aMsg);
+			cat.info(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 		}
 
 		else {
@@ -775,15 +735,14 @@ public class EPPRgpDomainTst extends TestCase {
 	/**
 	 * Print error message
 	 *
-	 * @param aMsg errpr message to print
+	 * @param aMsg
+	 *           errpr message to print
 	 */
 	private void printError(String aMsg) {
 		if (Thread.currentThread() instanceof TestThread) {
-			System.err.println(Thread.currentThread().getName()
-							   + ", iteration " + iteration + ": " + aMsg);
+			System.err.println(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 
-			cat.error(Thread.currentThread().getName() + ", iteration "
-					  + iteration + ": " + aMsg);
+			cat.error(Thread.currentThread().getName() + ", iteration " + iteration + ": " + aMsg);
 		}
 
 		else {
@@ -794,45 +753,33 @@ public class EPPRgpDomainTst extends TestCase {
 	} // End EPPRgpDomainTst.printError(String)
 
 	/**
-	 * Inspect the <code>EPPDomainInfoResp</code> and print out the 
-	 * RGP status information contained in the response.
+	 * Inspect the <code>EPPDomainInfoResp</code> and print out the RGP status
+	 * information contained in the response.
 	 * 
-	 * @param aResp Response to inspect
+	 * @param aResp
+	 *           Response to inspect
 	 */
 	private void printRgpStatuses(EPPDomainInfoResp aResp) {
 		// Check for the RGP grace period statuses
 		if (aResp.hasExtension(EPPRgpExtInfData.class)) {
-			EPPRgpExtInfData theRgpInf = (EPPRgpExtInfData) aResp
-					.getExtension(EPPRgpExtInfData.class);
+			EPPRgpExtInfData theRgpInf = (EPPRgpExtInfData) aResp.getExtension(EPPRgpExtInfData.class);
 			List rgpStatuses = theRgpInf.getStatuses();
-			System.out.println("domainInfo: rgpStatuses.size = "
-					+ rgpStatuses.size());
+			System.out.println("domainInfo: rgpStatuses.size = " + rgpStatuses.size());
 			for (int i = 0; i < rgpStatuses.size(); i++) {
-				EPPRgpExtStatus rgpStatus = (EPPRgpExtStatus) rgpStatuses
-						.get(i);
+				EPPRgpExtStatus rgpStatus = (EPPRgpExtStatus) rgpStatuses.get(i);
 
 				if (rgpStatus.getStatus().equals(EPPRgpExtStatus.ADD_PERIOD)
-						|| rgpStatus.getStatus().equals(
-								EPPRgpExtStatus.AUTO_RENEW_PERIOD)
-						|| rgpStatus.getStatus().equals(
-								EPPRgpExtStatus.RENEW_PERIOD)
-						|| rgpStatus.getStatus().equals(
-								EPPRgpExtStatus.TRANSFER_PERIOD)) {
-					System.out.println("domainInfo: rgp grace period status "
-							+ rgpStatus.getStatus());
-					System.out
-							.println("domainInfo: rgp grace period end date = "
-									+ EPPUtil.decodeTimeInstant(rgpStatus
-											.getMessage().substring(8)));
+				      || rgpStatus.getStatus().equals(EPPRgpExtStatus.AUTO_RENEW_PERIOD)
+				      || rgpStatus.getStatus().equals(EPPRgpExtStatus.RENEW_PERIOD)
+				      || rgpStatus.getStatus().equals(EPPRgpExtStatus.TRANSFER_PERIOD)) {
+					System.out.println("domainInfo: rgp grace period status " + rgpStatus.getStatus());
+					System.out.println("domainInfo: rgp grace period end date = "
+					      + EPPUtil.decodeTimeInstant(rgpStatus.getMessage().substring(8)));
 				}
-				else if (rgpStatus.getStatus().equals(
-						EPPRgpExtStatus.REDEMPTION_PERIOD)
-						|| rgpStatus.getStatus().equals(
-								EPPRgpExtStatus.PENDING_RESTORE)
-						|| rgpStatus.getStatus().equals(
-								EPPRgpExtStatus.PENDING_DELETE)) {
-					System.out.println("domainInfo: rgp pending period status "
-							+ rgpStatus.getStatus());
+				else if (rgpStatus.getStatus().equals(EPPRgpExtStatus.REDEMPTION_PERIOD)
+				      || rgpStatus.getStatus().equals(EPPRgpExtStatus.PENDING_RESTORE)
+				      || rgpStatus.getStatus().equals(EPPRgpExtStatus.PENDING_DELETE)) {
+					System.out.println("domainInfo: rgp pending period status " + rgpStatus.getStatus());
 
 				}
 
@@ -841,5 +788,4 @@ public class EPPRgpDomainTst extends TestCase {
 
 	}
 
-	
 } // End class EPPRgpDomainTst
