@@ -679,4 +679,15 @@ public class EPPSecDNSExtDsData implements EPPCodecComponent {
     public String toString() {
     	return EPPUtil.toString(this);
     }
+    
+   	/**
+   	 * Returns the XML namespace associated with the <code>EPPCodecComponent</code>.
+   	 * 
+   	 * @return XML namespace for the <code>EPPCodecComponent</code>. 
+   	 */
+   	@Override
+   	public String getNamespace() {
+   		return EPPSecDNSExtFactory.NS;
+   	}
+    
 }
\ No newline at end of file
